local Tablet = AceLibrary("Tablet-2.0")
local L = Rock("LibRockLocale-1.0"):GetTranslationNamespace("FuBar_RoutesFu")

RoutesFu = Rock:NewAddon("RoutesFu", "LibRockConfig-1.0", "LibRockDB-1.0", "LibFuBarPlugin-3.0")

RoutesFu:SetDatabase("RoutesFuDB")

RoutesFu:SetFuBarOption("hasIcon", true)
RoutesFu:SetFuBarOption("iconPath", "Interface\\Addons\\FuBar_RoutesFu\\icon.tga" )
RoutesFu:SetFuBarOption("defaultPosition", "RIGHT")
RoutesFu:SetFuBarOption("tooltipType", "Tablet-2.0")
RoutesFu:SetFuBarOption("clickableTooltip", true )
RoutesFu:SetFuBarOption("tooltipHiddenWhenEmpty", true)

local CR = Cartographer:GetModule("Routes")
local BZ = Rock("Babble-Zone-2.2")
local optionsTable = {
	name = "FuBar_RoutesFu",
	desc = RoutesFu.notes,
	handler = RoutesFu,
	type = "group",
	args = {
	}
}
local tmptable = {}

function RoutesFu:OnInitialize()
	RoutesFu:SetConfigTable(optionsTable)
	RoutesFu.OnMenuRequest = optionsTable

	-- These 4 lines is to fix some silly bug in LibFuBarPlugin-3.0 where both icon/text are
	-- hidden on first install and its not possible to register the icon to be shown by default
	RoutesFu:ToggleFuBarIconShown()
	RoutesFu:ToggleFuBarIconShown()
	RoutesFu:ToggleFuBarTextShown()
	RoutesFu:ToggleFuBarTextShown()
end

function RoutesFu:OnUpdateFuBarTooltip()
	local zone = GetRealZoneText()
	if BZ:HasReverseTranslation(zone) then
		zone = BZ:GetReverseTranslation(zone)
	end

	local header = Tablet:AddCategory(
		"columns", 2,
		"child_textR", 1,
		"child_textG", 1,
		"child_textB", 1,
		"child_text2R", 1,
		"child_text2G", 1,
		"child_text2B", 0
	)
	header:AddLine(
		"text", "Zone:",
		"text2", BZ[zone]
	)

	local zone_data = CR.db.account.routes[zone]

	if type(zone_data) == "table" then
		local toggle = Tablet:AddCategory(
			"columns", 2,
			"child_textR", 1,
			"child_textG", 1,
			"child_textB", 0,
			"child_text2R", 1,
			"child_text2G", 1,
			"child_text2B", 1,
			"child_indentation", 5,
			"hideBlankLine", true
		)

		for i = #tmptable, 1, -1 do
			tmptable[i] = nil
		end
		for route_name in pairs(zone_data) do
			tinsert(tmptable, route_name)
		end
		table.sort(tmptable)

		for i = 1, #tmptable do
			local route_name = tmptable[i]
			local route_data = zone_data[route_name]
			local checked = not route_data.hidden

			toggle:AddLine(
				"text", " "..route_name,
				"text2", L["%s nodes"]:format(#route_data.route),
				"hasCheck", true,
				"checked", checked,
				"func", "OnClickItem",
				"arg1", self,
				"arg2", zone,
				"arg3", route_name,
				"arg4", checked
			)
		end
	end
	Tablet:SetHint(L["Click route to toggle"])
	Tablet:SetTitle(L["Cartographer Routes"])
end

function RoutesFu:OnClickItem(zone, route_name, hidden)
	CR.db.account.routes[zone][route_name].hidden = hidden
	CR.DrawWorldmapLines()
end
